@@ -4,7 +4,7 @@ use Moo::Role;
 
 {
     use version 0.77;
-    $Pod::Readme::Plugin::requires::VERSION = version->declare('v1.0.3');
+    $Pod::Readme::Plugin::requires::VERSION = version->declare('v1.1.0');
 }
 
 use CPAN::Meta;
@@ -32,15 +32,19 @@ generated after that file has been updated.
 
 =head1 ARGUMENTS
 
-=head2 C<file>
+=head2 C<from-file>
 
-  =for readme plugin version file='MYMETA.yml'
+  =for readme plugin version from-file='MYMETA.yml'
 
 By default, it will extract the version from the F<META.yml> file. If,
 for some reason, this file is in a non-standard location, then you
 should specify it here.
 
-=head2 C<no-omit-coree>
+The file will be ignored if the C<zilla> attribute is set, and instead
+obtain metadata from the L<Dist::Zilla> object (since the F<META.yml>
+file may not exist.)
+
+=head2 C<no-omit-core>
 
 By default, core modules for the version of Perl specified in the
 F<META.yml> file are omitted from this list.  If you prefer to lise
@@ -113,8 +117,8 @@ has 'requires_run' => (
 );
 
 around 'depends_on' => sub {
-    my ($orig, $self) = @_;
-    return ($self->requires_from_file, $self->$orig);
+    my ( $orig, $self ) = @_;
+    return ( $self->requires_from_file, $self->$orig );
 };
 
 sub cmd_requires {
@@ -134,12 +138,24 @@ sub cmd_requires {
         }
     }
 
-    my $file = path( $self->base_dir, $self->requires_from_file )->stringify;
-    unless ( -e $file ) {
-        die "Cannot find META.yml file at '${file}";
-    }
+    my $meta;
 
-    my $meta = CPAN::Meta->load_file($file);
+    if ( $self->zilla ) {
+
+        $meta = CPAN::Meta->create( $self->zilla->distmeta,
+            { lazy_validation => 1 } );
+
+    }
+    else {
+
+        my $file =
+          path( $self->base_dir, $self->requires_from_file )->stringify;
+        unless ( -e $file ) {
+            die "Cannot find META.yml file at '${file}";
+        }
+
+        $meta = CPAN::Meta->load_file($file);
+    }
 
     my ( $prereqs, $perl ) = $self->_get_prereqs( $meta, 'requires' );
     if ( %{$prereqs} ) {
